@@ -3,6 +3,7 @@ try:
 except ImportError:
     import urllib2
     urlsplit = urllib2.urlparse.urlsplit
+import warnings
 import itertools
 import datetime
 
@@ -13,7 +14,10 @@ except NameError:
     basestring = str
 
 def parse(index):
-    for theclass in [basestring, datetime.date, datetime.datetime]:
+    if not safe_type(index):
+        warnings.warn(UserWarning('You should pass an object with a deterministic order. (probably not a %s)' % type(index).__name__))
+
+    for theclass in [basestring, datetime.date, datetime.datetime, int]:
         if isinstance(index, theclass):
             path = parse_partial(index)
             break
@@ -24,13 +28,21 @@ def parse(index):
 
 def parse_partial(item):
     if isinstance(item, basestring):
-        func = parse_partial_url
+        func = parse_partial_text
+    elif isinstance(item, int):
+        func = str
     elif isinstance(item, datetime.date) or isinstance(item, datetime.datetime):
         func = parse_partial_date
     else:
-        raise ValueError('item must be string, datetime.date or datetime.datetime')
+        raise ValueError('item must be string, datetime.date, datetime.datetime or int')
     return func(item)
 
+def parse_partial_text(item):
+    for a in parse_partial_url(item):
+        for b in a.split('\\'):
+            if b != '':
+                yield b
+
 def parse_partial_url(item):
     url = urlsplit(item)
     path = []
@@ -55,3 +67,10 @@ def parse_partial_url(item):
 
 def parse_partial_date(item):
     return ['%04d' % item.year, '%02d' % item.month, '%02d' % item.day]
+
+def safe_type(index):
+    for bad in [set,dict]:
+        if isinstance(index, bad):
+            return False
+    else:
+        return True
